@@ -15,8 +15,8 @@ tables can be accessed [*]_.
 FSLeyes colour maps and lookup tables are stored in the following locations:
 
 
-   - ``[assetsbase]/assets/colourmaps/``
-   - ``[assetsbase]/assets/luts/``
+   - ``[assetsbase]/colourmaps/``
+   - ``[assetsbase]/luts/``
    - ``[settingsbase]/colourmaps/``
    - ``[settingsbase]/luts/``
 
@@ -72,6 +72,7 @@ The following functions are available for managing and accessing colour maps:
    getColourMap
    getColourMapLabel
    getColourMapFile
+   loadColourMapFile
    registerColourMap
    installColourMap
    isColourMapRegistered
@@ -85,11 +86,15 @@ Display name and ordering
 For built-in colour maps, a file named ``[assetsbase]/colourmaps/order.txt``
 is assumed to contain a list of colour map names, and colour map identifiers,
 defining the order in which the colour maps should be displayed to the
-user. Any colour maps which are present in ``[assetsbase/colourmaps/``, but
+user. Any colour maps which are present in ``[assetsbase]/colourmaps/``, but
 are not listed in the ``order.txt``, file will be appended to the end of the
 list, and their name will be derived from the file name.
 
 
+If a file ``[settingsbase]/colourmaps/order.txt`` exists, then it will be used
+in place of the ``order.txt`` file in ``[assetsbase]``.
+
+
 User-added colour maps
 ^^^^^^^^^^^^^^^^^^^^^^
 
@@ -157,6 +162,7 @@ access and manage :class:`LookupTable` instances:
    getLookupTables
    getLookupTable
    getLookupTableFile
+   loadLookupTableFile
    registerLookupTable
    installLookupTable
    isLookupTableRegistered
@@ -174,6 +180,7 @@ for querying installed colour maps and lookup tables,
 .. autosummary::
    :nosignatures:
 
+   fileType
    getCmapDir
    getLutDir
    scanBuiltInCmaps
@@ -193,6 +200,7 @@ colours:
 
    displayRangeToBricon
    briconToDisplayRange
+   briconToScaleOffset
    applyBricon
    randomColour
    randomBrightColour
@@ -201,24 +209,27 @@ colours:
 """
 
 
-import os.path as op
-import            os
-import            glob
-import            bisect
-import            string
-import            logging
-import            colorsys
+import itertools as it
+import functools as ft
+import os.path   as op
+import              os
+import              bisect
+import              string
+import              logging
+import              colorsys
 
-from collections import OrderedDict
+import numpy             as np
+import matplotlib        as mpl
+import matplotlib.cm     as mplcm
+import matplotlib.colors as colors
 
-import          six
-import numpy as np
-
-import fsleyes_props      as props
-import                       fsleyes
-import fsl.utils.settings as fslsettings
-import fsl.utils.notifier as notifier
-import fsl.data.vest      as vest
+import fsl.version            as fslversion
+import fsl.utils.settings     as fslsettings
+import fsl.utils.notifier     as notifier
+import fsl.data.vest          as vest
+import fsleyes_props          as props
+import                           fsleyes
+import fsleyes.displaycontext as fsldisplay
 
 
 log = logging.getLogger(__name__)
@@ -227,31 +238,72 @@ log = logging.getLogger(__name__)
 def getCmapDir():
     """Returns the directory in which all built-in colour map files are stored.
     """
-    return op.join(fsleyes.assetDir, 'assets', 'colourmaps')
+    return op.join(fsleyes.assetDir, 'colourmaps')
 
 
 def getLutDir():
     """Returns the directory in which all built-in lookup table files are stored.
     """
-    return op.join(fsleyes.assetDir, 'assets', 'luts')
+    return op.join(fsleyes.assetDir, 'luts')
+
+
+def _walk(dirname, suffix):
+    """Recursively searches ``dirname``, returning a list of all files with the
+    specified ``suffix``.
+    """
+    matches = []
+    for dirpath, dirnames, filenames in os.walk(dirname):
+        for filename in filenames:
+            if filename.endswith(suffix):
+                matches.append(op.join(dirpath, filename))
+    return matches
+
+
+def _find(mapid, dirname):
+    """Finds the file associated with the given (built-in) colour map or lookup
+    table ID.
+    """
+
+    divs     = [i for i, c in enumerate(mapid) if c == '_']
+    pathopts = it.chain(*[it.combinations(divs, n)
+                          for n in range(len(divs) + 1)])
+
+    for pathidxs in pathopts:
+
+        path = mapid
+        for i in pathidxs:
+            path = path[:i] + op.sep + path[i + 1:]
+
+        path = op.join(dirname, path)
+
+        if op.exists(path):
+            return path
+
+    raise ValueError('Cannot find {} in {}'.format(mapid, dirname))
 
 
 def scanBuiltInCmaps():
     """Returns a list of IDs for all built-in colour maps. """
 
-    cmapIDs  = glob.glob(op.join(getCmapDir(), '*.cmap'))
-    cmapIDs  = [op.splitext(op.basename(f))[0] for f in cmapIDs]
+    basedir = getCmapDir()
+    cmapIDs = _walk(basedir, '.cmap')
+    cmapIDs = [op.splitext(i)[0]      for i in cmapIDs]
+    cmapIDs = [op.relpath(i, basedir) for i in cmapIDs]
+    cmapIDs = [i.replace(op.sep, '_') for i in cmapIDs]
 
-    return cmapIDs
+    return list(sorted(cmapIDs))
 
 
 def scanBuiltInLuts():
     """Returns a list of IDs for all built-in lookup tables. """
 
-    lutIDs = glob.glob(op.join(getLutDir(), '*.lut'))
-    lutIDs = [op.splitext(op.basename(f))[0] for f in lutIDs]
+    basedir = getLutDir()
+    lutIDs  = _walk(basedir, '.lut')
+    lutIDs  = [op.splitext(i)[0]      for i in lutIDs]
+    lutIDs  = [op.relpath(i, basedir) for i in lutIDs]
+    lutIDs  = [i.replace(op.sep, '_') for i in lutIDs]
 
-    return lutIDs
+    return list(sorted(lutIDs))
 
 
 def scanUserAddedCmaps():
@@ -262,7 +314,7 @@ def scanUserAddedCmaps():
     cmapIDs   = [op.splitext(f)[0] for f in cmapFiles]
     cmapIDs   = [m.lower()         for m in cmapIDs]
 
-    return cmapIDs
+    return list(sorted(cmapIDs))
 
 
 def scanUserAddedLuts():
@@ -273,7 +325,7 @@ def scanUserAddedLuts():
     lutIDs   = [op.splitext(f)[0] for f in lutFiles]
     lutIDs   = [m.lower()         for m in lutIDs]
 
-    return lutIDs
+    return list(sorted(lutIDs))
 
 
 def makeValidMapKey(name):
@@ -295,7 +347,7 @@ def isValidMapKey(key):
     """
 
     valid = string.ascii_lowercase + string.digits + '_-'
-    return all([c in valid for c in key])
+    return all(c in valid for c in key)
 
 
 def scanColourMaps():
@@ -315,14 +367,14 @@ def scanLookupTables():
 
 
 _cmaps = None
-"""An ``OrderedDict`` which contains all registered colour maps as
-``{key : _Map}`` mappings.
+"""A dict which contains all registered colour maps as ``{key : _Map}``
+mappings.
 """
 
 
 _luts = None
-"""An ``OrderedDict`` which contains all registered lookup tables as
-``{key : _Map}`` mappings.
+"""A dict which contains all registered lookup tables as ``{key : _Map}``
+mappings.
 """
 
 
@@ -344,15 +396,15 @@ def init(force=False):
     if not force and (_cmaps is not None) and (_luts is not None):
         return
 
-    _cmaps = OrderedDict()
-    _luts  = OrderedDict()
+    _cmaps = {}
+    _luts  = {}
 
     # Reads the order.txt file from the built-in
     # /colourmaps/ or /luts/ directory. This file
     # contains display names and defines the order
     # in which built-in maps should be displayed.
     def readOrderTxt(filename):
-        maps = OrderedDict()
+        maps = {}
 
         if not op.exists(filename):
             return maps
@@ -380,7 +432,7 @@ def init(force=False):
     def readDisplayNames(mapType):
         if   mapType == 'cmap': key = 'fsleyes.colourmaps'
         elif mapType == 'lut':  key = 'fsleyes.luts'
-        return fslsettings.read(key, OrderedDict())
+        return fslsettings.read(key, {})
 
     # Get all colour map/lut IDs and
     # paths to the cmap/lut files. We
@@ -399,21 +451,30 @@ def init(force=False):
             mapTypes, builtinDirs, userDirs, allBuiltins, allUsers, registers):
 
         builtinFiles = ['{}.{}'.format(m, mapType) for m in builtinIDs]
-        builtinFiles = [op.join(builtinDir, m)     for m in builtinFiles]
+        builtinFiles = [_find(m, builtinDir)       for m in builtinFiles]
         userFiles    = ['{}.{}'.format(m, mapType) for m in userIDs]
         userFiles    = [op.join(userDir, m)        for m in userFiles]
         userFiles    = [fslsettings.filePath(m)    for m in userFiles]
 
         allIDs   = builtinIDs   + userIDs
         allFiles = builtinFiles + userFiles
-        allFiles = {mid : mfile for mid, mfile in zip(allIDs, allFiles)}
+        allFiles = dict(zip(allIDs, allFiles))
 
-        # Read order/display names from order.txt
-        # (for builtins), and from fslsettings
-        # (for user-added). Any user-added maps
-        # with the same as a builtin will override
+        # Read order/display names from order.txt -
+        # if an order.txt file exists in the user
+        # dir, it takes precednece over built-in
+        # order/display names.
+        #
+        # User-added display names may also be in
+        # fslsettings. Any user-added maps with
+        # the same ID as a builtin will override
         # the builtin.
-        names = readOrderTxt(op.join(builtinDir, 'order.txt'))
+        builtinOrder = op.join(builtinDir, 'order.txt')
+        userOrder    = op.join(userDir,    'order.txt')
+
+        if op.exists(userOrder): names = readOrderTxt(userOrder)
+        else:                    names = readOrderTxt(builtinOrder)
+
         names.update(readDisplayNames(mapType))
 
         # any maps which did not have a name
@@ -481,10 +542,9 @@ def registerColourMap(cmapFile,
 
     :arg name:        Display name for the colour map. If ``None``, defaults
                       to the ``name``.
-    """
 
-    import matplotlib.cm     as mplcm
-    import matplotlib.colors as colors
+    :returns:         The key that the ``ColourMap`` was registered under.
+    """
 
     if key is not None and not isValidMapKey(key):
         raise ValueError('{} is not a valid colour map identifier'.format(key))
@@ -496,28 +556,26 @@ def registerColourMap(cmapFile,
     if name        is None: name        = key
     if overlayList is None: overlayList = []
 
-    # The file could be a FSLView style VEST-LUT
-    if vest.looksLikeVestLutFile(cmapFile):
-        data = vest.loadVestLutFile(cmapFile, normalise=False)
-
-    # Or just a plain 2D text array
-    else:
-        data = np.loadtxt(cmapFile)
-
+    data = loadColourMapFile(cmapFile)
     cmap = colors.ListedColormap(data, key)
 
     log.debug('Loading and registering custom '
               'colour map: {}'.format(cmapFile))
 
-    mplcm.register_cmap(key, cmap)
+    # matplotlib 3.3.4 and newer will raise an error
+    # when trying to register a colour map with the
+    # same name as a built-in, unless override_builtin
+    # (also added in that version) is set to True.
+    if fslversion.compareVersions(mpl.__version__, '3.3.4') > 0:
+        mplcm.register_cmap(key, cmap, override_builtin=True)
+    else:
+        mplcm.register_cmap(key, cmap)
 
     _cmaps[key] = _Map(key, name, cmap, cmapFile, False)
 
     log.debug('Patching DisplayOpts instances and class '
               'to support new colour map {}'.format(key))
 
-    import fsleyes.displaycontext as fsldisplay
-
     # A list of all DisplayOpts colour map properties.
     # n.b. We can't simply list the ColourMapOpts class
     # here, because it is a mixin, and does not actually
@@ -548,6 +606,8 @@ def registerColourMap(cmapFile,
         prop = cls.getProp(propName)
         prop.addColourMap(key)
 
+    return key
+
 
 def registerLookupTable(lut,
                         overlayList=None,
@@ -576,10 +636,12 @@ def registerLookupTable(lut,
 
     :arg name:        Display name for the lookup table. If ``None``, defaults
                       to the ``name``.
+
+    :returns:         The :class:`LookupTable` object
     """
 
-    if isinstance(lut, six.string_types): lutFile = lut
-    else:                                 lutFile = None
+    if isinstance(lut, str): lutFile = lut
+    else:                    lutFile = None
 
     if overlayList is None:
         overlayList = []
@@ -616,8 +678,6 @@ def registerLookupTable(lut,
     log.debug('Patching LabelOpts classes to support '
               'new LookupTable {}'.format(key))
 
-    import fsleyes.displaycontext as fsldisplay
-
     # See similar situation in the registerColourMap
     # function above. All DisplayOpts classes which
     # have a lut property (assumed to be a props.Choice)
@@ -739,7 +799,7 @@ def installColourMap(key):
         np.savetxt(f, data, '%0.6f')
 
     # Update user-added settings
-    cmapNames      = fslsettings.read('fsleyes.colourmaps', OrderedDict())
+    cmapNames      = fslsettings.read('fsleyes.colourmaps', {})
     cmapNames[key] = cmap.name
 
     fslsettings.write('fsleyes.colourmaps', cmapNames)
@@ -766,7 +826,7 @@ def installLookupTable(key):
     lut.mapObj.save(destFile)
 
     # Update user-added settings
-    lutNames      = fslsettings.read('fsleyes.luts', OrderedDict())
+    lutNames      = fslsettings.read('fsleyes.luts', {})
     lutNames[key] = lut.name
     fslsettings.write('fsleyes.luts', lutNames)
 
@@ -774,12 +834,154 @@ def installLookupTable(key):
     lut.installed = True
 
 
+##########
+# File I/O
+##########
+
+
+def fileType(fname):
+    """Attempts to guess the type of ``fname``.
+
+    ``fname`` is assumed to be a FSLeyes colour map or lookup table file,
+    or a FSLView-style VEST lookup table file.
+
+    A ``ValueError`` is raised if the file type cannot be determined.
+
+    :arg fname: Name of file to check
+
+    :returns:   One of ``'vest'``, ``'cmap'``, or ``'lut'``, depending on
+                what the contents of ``fname`` look like.
+    """
+
+    if vest.looksLikeVestLutFile(fname):
+        return 'vest'
+
+    with open(fname, 'rt') as f:
+        for line in f:
+            line = f.readline().strip()
+            if (line != '') and (not line.startswith('#')):
+                break
+
+    tkns = list(line.split())
+
+    # cmap file
+    if len(tkns) == 3:
+        try:
+            [float(t) for t in tkns]
+            return 'cmap'
+        except ValueError:
+            pass
+
+    # lut file
+    elif len(tkns) >= 4:
+        try:
+            [float(t) for t in tkns[:4]]
+            return 'lut'
+        except ValueError:
+            pass
+
+    raise ValueError('Cannot determine type of {}'.format(fname))
+
+
+def loadColourMapFile(fname, aslut=False):
+    """Load the given file, assumed to be a colour map.
+
+    :arg fname: FSLeyes or FSLView (VEST) colour map file
+
+    :arg aslut: If ``True``, the returned array will contain a label for
+                each colour, ranging from ``1`` to ``N``, where ``N`` is
+                the number of colours in the file.
+
+    :returns:   A ``numpy`` array of shape ``(N, 3)`` containing the
+                RGB values for ``N`` colours. Or, if ``aslut is True``,
+                A ``numpy`` array of shape ``(N, 4)`` containing a
+                label, and the RGB values for ``N`` colours.
+    """
+
+    # The file could be a FSLView style VEST LUT
+    if vest.looksLikeVestLutFile(fname):
+        data = vest.loadVestLutFile(fname, normalise=False)
+
+    # Or just a plain 2D text array
+    else:
+        data = np.loadtxt(fname)
+
+    if aslut:
+        lbls = np.arange(1, data.shape[0] + 1).reshape(-1, 1)
+        data = np.hstack((lbls, data))
+
+    return data
+
+
+def loadLookupTableFile(fname):
+    """Loads the given file, assumed to be a lookup table.
+
+    :arg fname: Name of a FSLeyes lookup table file.
+
+    :returns:   A tuple containing:
+
+                 - A ``numpy`` array of shape ``(N, 4)`` containing the
+                   label and RGB values for ``N`` colours.
+                 - A list containin the name for each label
+
+    .. note:: The provided file may also be a colour map file (see
+              :func:`loadColourMapFile`), in which case the labels will range
+              from ``1`` to ``N``, and the names will be strings containing
+              the label values.
+    """
+
+    # Accept cmap file, auto-generate labels/names
+    if fileType(fname) in ('vest', 'cmap'):
+        lut   = loadColourMapFile(fname, aslut=True)
+        names = ['{}'.format(int(l)) for l in lut[:, 0]]
+        return lut, names
+
+    # Otherwise assume a FSLeyes lut file
+    with open(fname, 'rt') as f:
+
+        # Read the LUT label/colours on
+        # a first pass through the file
+        struclut = np.genfromtxt(
+            f,
+            usecols=(0, 1, 2, 3),
+            dtype={
+                'formats' : (int, float, float, float),
+                'names'   : ('label', 'r', 'g', 'b')})
+
+        # Save the label ordering -
+        # we'll use it below
+        order     = struclut.argsort(order='label')
+
+        # Convert from a structured
+        # array into a regular array
+        lut       = np.zeros((len(struclut), 4), dtype=np.float32)
+        lut[:, 0] = struclut['label']
+        lut[:, 1] = struclut['r']
+        lut[:, 2] = struclut['g']
+        lut[:, 3] = struclut['b']
+
+        # Read the names on a second pass
+        f.seek(0)
+        names = []
+        for i, line in enumerate(f):
+            tkns = line.split(None, 4)
+            if len(tkns) < 5: name = '{}'.format(int(lut[i, 0]))
+            else:             name = tkns[4].strip()
+            names.append(name)
+
+    # Sort by ascending label value
+    lut   = lut[order, :]
+    names = [names[o] for o in order]
+
+    return lut, names
+
+
 ###############
 # Miscellaneous
 ###############
 
 
-def _briconToScaleOffset(brightness, contrast, drange):
+def briconToScaleOffset(brightness, contrast, drange):
     """Used by the :func:`briconToDisplayRange` and the :func:`applyBricon`
     functions.
 
@@ -832,7 +1034,7 @@ def briconToDisplayRange(dataRange, brightness, contrast):
     drange     = dmax - dmin
     dmid       = dmin + 0.5 * drange
 
-    scale, offset = _briconToScaleOffset(brightness, contrast, drange)
+    scale, offset = briconToScaleOffset(brightness, contrast, drange)
 
     # Calculate the new display range, keeping it
     # centered in the middle of the data range
@@ -862,7 +1064,7 @@ def displayRangeToBricon(dataRange, displayRange):
         return 0, 0
 
     # These are inversions of the equations in
-    # the _briconToScaleOffset function above,
+    # the briconToScaleOffset function above,
     # which calculate the display ranges from
     # the bricon offset/scale
     offset = dlo + 0.5 * (dhi - dlo) - dmid
@@ -900,7 +1102,7 @@ def applyBricon(rgb, brightness, contrast):
     oneColour = len(rgb.shape) == 1
     rgb       = rgb.reshape(-1, rgb.shape[-1])
 
-    scale, offset = _briconToScaleOffset(brightness, contrast, 1)
+    scale, offset = briconToScaleOffset(brightness, contrast, 1)
 
     # The contrast factor scales the existing colour
     # range, but keeps the new range centred at 0.5.
@@ -998,14 +1200,14 @@ def _caseInsensitiveLookup(d, k, default=None):
 
     try:
         idx = lKeys.index(k.lower())
-    except:
+    except Exception:
         if default is not None: return default
         else:                   raise  KeyError(k)
 
     return d[keys[idx]]
 
 
-class _Map(object):
+class _Map:
     """A little class for storing details on registered colour maps and lookup
     tables. This class is only used internally.
     """
@@ -1142,9 +1344,9 @@ class LutLabel(props.HasProperties):
         """The hash of a ``LutLabel`` is a combination of its
         value, name, and colour, but not its enabled state.
         """
-        return (hash(self.value)        ^
-                hash(self.internalName) ^
-                hash(self.colour))
+        return hash(      self.value)        ^ \
+               hash(      self.internalName) ^ \
+               hash(tuple(self.colour))
 
 
     def __str__(self):
@@ -1227,8 +1429,8 @@ class LookupTable(notifier.Notifier):
         self.__toParse = None
 
         if lutFile is not None:
-            self.__toParse = self.__load(lutFile)
-            self.__savbed  = True
+            self.__toParse = loadLookupTableFile(lutFile)
+            self.__saved   = True
 
 
     def lazyparse(func):
@@ -1242,7 +1444,7 @@ class LookupTable(notifier.Notifier):
                 self.__toParse = None
                 self.__parsed  = True
             return func(self, *args, **kwargs)
-        return wrapper
+        return ft.update_wrapper(wrapper, func)
 
 
     def __str__(self):
@@ -1357,10 +1559,11 @@ class LookupTable(notifier.Notifier):
 
         :returns: The newly created ``LutLabel`` instance.
         """
-        if not isinstance(value, six.integer_types) or \
+        if not isinstance(value, (int, np.integer)) or \
            value < 0 or value > 65535:
             raise ValueError('Lookup table values must be '
-                             '16 bit unsigned integers.')
+                             '16 bit unsigned integers ({}: {}).'.format(
+                                 type(value), value))
 
         if self.get(value) is not None:
             raise ValueError('Value {} is already in '
@@ -1405,7 +1608,6 @@ class LookupTable(notifier.Notifier):
                 value  = label.value
                 colour = label.colour
                 name   = label.name
-
                 tkns   = [value, colour[0], colour[1], colour[2], name]
                 line   = ' '.join(map(str, tkns))
 
@@ -1417,7 +1619,7 @@ class LookupTable(notifier.Notifier):
     def __parse(self, lut, names):
         """Parses ``lut``, a numpy array containing a LUT. """
 
-        labels = [LutLabel(l, name, (r, g, b), l > 0)
+        labels = [LutLabel(int(l), name, (r, g, b), l > 0)
                   for ((l, r, g, b), name) in zip(lut, names)]
 
         self.__labels = labels
@@ -1426,28 +1628,6 @@ class LookupTable(notifier.Notifier):
             label.addGlobalListener(self.__name, self.__labelChanged)
 
 
-    def __load(self, lutFile):
-        """Called by :meth:`__init__`. Loads a ``LookupTable`` specification
-        from the given file.
-        """
-
-        with open(lutFile, 'rt') as f:
-            lut = np.genfromtxt(
-                f,
-                usecols=(0, 1, 2, 3),
-                dtype={
-                    'formats' : (np.int, np.float, np.float, np.float),
-                    'names'   : ('label', 'r', 'g', 'b')})
-            f.seek(0)
-            names = [l.split(None, 4)[4].strip() for l in f]
-
-        order = lut.argsort(order='label')
-        lut   = lut[order]
-        names = [names[o] for o in order]
-
-        return lut, names
-
-
     def __labelChanged(self, value, valid, label, propName):
         """Called when the properties of any ``LutLabel`` change. Triggers
         notification on the ``label`` topic.
