@@ -118,6 +118,8 @@ class SliceCanvas(object):
        :nosignatures:
 
        canvasToWorld
+       worldToCanvas
+       pixelSize
        panDisplayBy
        centreDisplayAt
        panDisplayToShow
@@ -267,6 +269,7 @@ class SliceCanvas(object):
         self._offscreenTextures = None
 
 
+    @property
     def destroyed(self):
         """Returns ``True`` if a call to :meth:`destroy` has been made,
         ``False`` otherwise.
@@ -311,6 +314,48 @@ class SliceCanvas(object):
         return pos
 
 
+    def worldToCanvas(self, pos):
+        """Converts a location in the display coordinate system into
+        an x/y location in pixels relative to this ``SliceCanvas``.
+        """
+
+        opts    = self.opts
+        xpos    = pos[opts.xax]
+        ypos    = pos[opts.yax]
+        invertX = opts.invertX
+        invertY = opts.invertY
+
+        xmin          = opts.displayBounds.xlo
+        xlen          = opts.displayBounds.xlen
+        ymin          = opts.displayBounds.ylo
+        ylen          = opts.displayBounds.ylen
+        width, height = [float(s) for s in self.GetSize()]
+
+        if xlen   == 0 or \
+           ylen   == 0 or \
+           width  == 0 or \
+           height == 0:
+            return None
+
+        xpos = width  * ((xpos - xmin) / xlen)
+        ypos = height * ((ypos - ymin) / ylen)
+
+        if invertX: xpos = width  - xpos
+        if invertY: ypos = height - ypos
+
+        return xpos, ypos
+
+
+    def pixelSize(self):
+        """Returns the current (x, y) size of one logical pixel in display
+        coordinates.
+        """
+        w, h = self.GetSize()
+        xlen = self.opts.displayBounds.xlen
+        ylen = self.opts.displayBounds.ylen
+        return (xlen / w, ylen / h)
+
+
     def panDisplayBy(self, xoff, yoff):
         """Pans the canvas display by the given x/y offsets (specified in
         display coordinates).
@@ -476,6 +521,18 @@ class SliceCanvas(object):
         return self.__viewport
 
 
+    @property
+    def viewMatrix(self):
+        """Returns the current model view matrix. """
+        return gl.glGetFloat(gl.GL_MODELVIEW_MATRIX)
+
+
+    @property
+    def projectionMatrix(self):
+        """Returns the current projection matrix. """
+        return gl.glGetFloat(gl.GL_PROJECTION_MATRIX)
+
+
     def _initGL(self):
         """Call the :meth:`_overlayListChanged` method - it will generate
         any necessary GL data for each of the overlays.
@@ -762,7 +819,7 @@ class SliceCanvas(object):
 
         def create():
 
-            if not self or self.destroyed():
+            if not self or self.destroyed:
                 return
 
             # The overlay has been removed from the
@@ -833,6 +890,11 @@ class SliceCanvas(object):
         redrawn.
         """
 
+        # we can sometimes get called after
+        # being destroyed (e.g. during testing)
+        if self.destroyed:
+            return
+
         # If we are in prerender mode, we
         # need to tell the RenderTextureStack
         # for this GLObject to update itself.
@@ -856,6 +918,9 @@ class SliceCanvas(object):
         overlay.
         """
 
+        if self.destroyed:
+            return
+
         # Destroy any GL objects for overlays
         # which are no longer in the list
         for ovl, globj in list(self._glObjects.items()):
@@ -888,7 +953,7 @@ class SliceCanvas(object):
             # This SliceCanvas might get
             # destroyed before this idle
             # task is executed
-            if not self or self.destroyed():
+            if not self or self.destroyed:
                 return
 
             self._updateRenderTextures()
@@ -1279,8 +1344,8 @@ class SliceCanvas(object):
         # Just show a vertical line at xpos,
         # and a horizontal line at ypos
         if not copts.cursorGap:
-            lines.append(((x,    ymin), (x,    ymax)))
-            lines.append(((xmin, y),    (xmax, y)))
+            lines.append((x,    ymin, x,    ymax))
+            lines.append((xmin, y,    xmax, y))
 
         # Draw vertical/horizontal cursor lines,
         # with a gap at the cursor centre
@@ -1289,10 +1354,10 @@ class SliceCanvas(object):
         # use a fixed gap size
         elif ovl is None or not isinstance(ovl, fslimage.Nifti):
 
-            lines.append(((xmin,    y),       (x - 0.5, y)))
-            lines.append(((x + 0.5, y),       (xmax,    y)))
-            lines.append(((x,       ymin),    (x,       y - 0.5)))
-            lines.append(((x,       y + 0.5), (x,       ymax)))
+            lines.append((xmin,    y,       x - 0.5, y))
+            lines.append((x + 0.5, y,       xmax,    y))
+            lines.append((x,       ymin,    x,       y - 0.5))
+            lines.append((x,       y + 0.5, x,       ymax))
 
         # If the current overlay is NIFTI, make
         # the gap size match its voxel size
@@ -1350,10 +1415,10 @@ class SliceCanvas(object):
                 ylow  = min(vloc[copts.yax], vlocy[copts.yax])
                 yhigh = max(vloc[copts.yax], vlocy[copts.yax])
 
-            lines.append(((xmin,  y),     (xlow, y)))
-            lines.append(((xhigh, y),     (xmax, y)))
-            lines.append(((x,     ymin),  (x,    ylow)))
-            lines.append(((x,     yhigh), (x,    ymax)))
+            lines.append((xmin,  y,     xlow, y))
+            lines.append((xhigh, y,     xmax, y))
+            lines.append((x,     ymin,  x,    ylow))
+            lines.append((x,     yhigh, x,    ymax))
 
         kwargs = {
             'colour' : copts.cursorColour,
@@ -1361,8 +1426,8 @@ class SliceCanvas(object):
         }
 
         for line in lines:
-            self._annotations.line(line[0], line[1], **kwargs)
-            self._annotations.line(line[0], line[1], **kwargs)
+            self._annotations.line(*line, **kwargs)
+            self._annotations.line(*line, **kwargs)
 
 
     def _drawOffscreenTextures(self):
@@ -1403,7 +1468,7 @@ class SliceCanvas(object):
     def _draw(self, *a):
         """Draws the current scene to the canvas. """
 
-        if self.destroyed():
+        if self.destroyed:
             return
 
         width, height = self.GetSize()
@@ -1422,7 +1487,7 @@ class SliceCanvas(object):
 
         # Set the viewport to match the current
         # display bounds and canvas size
-        if copts.renderMode is not 'offscreen':
+        if copts.renderMode != 'offscreen':
             bbox = self._setViewport()
             glroutines.clear(copts.bgColour)
 
@@ -1477,7 +1542,7 @@ class SliceCanvas(object):
                           'to off-screen texture'.format(
                               copts.zax, overlay.name))
 
-                with rt.bound(copts.xax, copts.yax, lo, hi),  \
+                with rt.target(copts.xax, copts.yax, lo, hi),  \
                      glroutines.disabled(gl.GL_BLEND):
 
                     glroutines.clear((0, 0, 0, 0))
