@@ -84,6 +84,9 @@ properties = TypeDict({
     'Data clipping range - voxels with values outside of this range will not '
     'be displayed.',
 
+    'ColourMapOpts.modulateRange' :
+    'Modulation range - controls the data range used to modulate transparency',
+
     'ColourMapOpts.invertClipping' :
     'Invert the clipping range, so that voxels inside the range are not '
     'displayed, and voxels outside of the range are displayed. '
@@ -110,6 +113,20 @@ properties = TypeDict({
     'Invert the display range, so that the low value corresponds to the high '
     'colour, and vice versa.',
 
+    'ColourMapOpts.modulateAlpha' :
+    'Modulate alpha (opacity) by the intensity at each region. Regions with a '
+    'value near to the low display range will have opacity near 0, and '
+    'regions with a value near to the high display range will have opacity '
+    'near 1.',
+
+    'ColourMapOpts.gamma' :
+    'Apply an exponential factor to to give more weighting to lower or higher '
+    'values. ',
+
+    'ColourMapOpts.logScale' :
+    'Map intensities to colours logarithmically (using the natural logarithm) '
+    'rather than linearly. ',
+
     'VolumeOpts.interpolation' :
     'Interpolate the image data on the display. You can choose no  '
     'interpolation (equivalent to nearest neighbour interpolation), linear '
@@ -130,6 +147,15 @@ properties = TypeDict({
     'one. This is useful for images which have a very large data '
     'range that is driven by outliers.',
 
+    'VolumeOpts.clipImage' :
+    'Clip this image by the values contained in another image. When active, '
+    'The clipping range is set according to the values in the clip image '
+    'instead of in this image.',
+
+    'VolumeOpts.modulateImage' :
+    'Modulate alpha/opacity by the values contained in another image, instead '
+    'of modulating by the values in this image.',
+
     'Volume3DOpts.numSteps' :
     'The maximum number of times that the image is sampled for each pixel.',
 
@@ -138,6 +164,11 @@ properties = TypeDict({
     'in the final volume colour being blended from samples which are deeper '
     'in the volume.',
 
+    'Volume3DOpts.blendByIntensity' :
+    'When active, the amount by which each sample is blended into the final '
+    'colour will be weighted by the voxel intensity. When inactive, samples '
+    'will be blended solely according to the blending setting.',
+
     'Volume3DOpts.smoothing' :
     'This setting controls the amount of smoothing applied to the volume. '
     'When the smoothing is greater than zero, a gaussian smoothing filter is '
@@ -169,6 +200,10 @@ properties = TypeDict({
     'Volume3DOpts.clipAzimuth' :
     'Amount by which to rotate the clip plane about the Z axis.',
 
+    'ComplexOpts.component' :
+    'Choose to display either the real or imaginary components, or the '
+    'magnitude or phase.',
+
     'MaskOpts.colour' :
     'The colour of this mask image.',
     'MaskOpts.invert' :
@@ -260,6 +295,9 @@ properties = TypeDict({
     'VectorOpts.modulateRange'    : 'The data range that is used when '
                                     'modulating vector brightness by a '
                                     'modulation image.',
+    'VectorOpts.modulateMode'     : 'Either the brightness, or the '
+                                    'transparency, of vector voxels can be '
+                                    'modulated by the modulation image.',
     'VectorOpts.cmap'             : 'Colour map to use for colouring vector '
                                     'voxels, if a colour image is selected.',
     'VectorOpts.orientFlip'       : 'If checked, direction orientations '
@@ -288,6 +326,9 @@ properties = TypeDict({
                                     'purposes. You can choose none '
                                     '(equivalent to nearest-neighbour), '
                                     'linear, or spline interpolation.',
+    'RGBVectorOpts.unitLength'    : 'If checked, the data is scaled so that '
+                                    'each vector has length 1.',
+
 
     'MeshOpts.colour' :
     'The colour of the mesh, when not colouring by vertex data.',
@@ -317,6 +358,9 @@ properties = TypeDict({
     'Choose a file which contains data for each vertex - you can colour the '
     'mesh outline according to the values in the file. This only applies '
     'when the mesh outline, and not its cross-section is displayed.',
+    'MeshOpts.modulateData' :
+    'Choose a vertex data file to modulate transparency by. If left unset, '
+    'transparency is modulated by the currently selected vertex data.',
     'MeshOpts.custom_vertexData'   :
     'Choose a file which contains data for each vertex - you can colour the '
     'mesh outline according to the values in the file. This only applies '
@@ -344,7 +388,10 @@ properties = TypeDict({
     'filled.',
     'MeshOpts.lighting' :
     'When selected, a lighting effect is applied to the mesh.',
-
+    'MeshOpts.flatShading' :
+    'When selected, interpolation of the colours between adjacent vertices'
+    'is not performed - each triangle in the mesh is coloured according to '
+    'its first triangle.',
 
     'TensorOpts.lighting'         : 'If enabled, a simple lighting model is '
                                     'used to highlight the tensor '
@@ -380,8 +427,23 @@ properties = TypeDict({
                                 'disabled when you choose to colour the FODs '
                                 'by another image (e.g. a FA map).',
 
-    # SceneOpts
+    # MIPOpts
+    'MIPOpts.window'  :
+    'Length of the window, as a proportion of the image length, along which '
+    'the MIP is calculated. The window is centred at the current display '
+    'location.',
+    'MIPOpts.minimum' :
+    'Use the minimum intensity, rather than the maximum intensity, in the '
+    'projection.',
+    'MIPOpts.absolute' :
+    'Use the absolute intensity, rather than the maximum intensity, in the '
+    'projection. This overrides the minimum intensity setting.',
+    'MIPOpts.interpolation' :
+    'Interpolate the MIP data on the display. You can choose no  '
+    'interpolation (equivalent to nearest neighbour interpolation), linear '
+    'interpolation, or third-order spline (cubic) interpolation.',
 
+    # SceneOpts
     'SceneOpts.showCursor'         : 'Show/hide the cursor which highlights '
                                      'the current location.',
     'SceneOpts.cursorGap'          : 'Show a gap at the cursor centre.',
@@ -399,6 +461,9 @@ properties = TypeDict({
     'SceneOpts.colourBarLocation'  : 'Where to display the colour bar.',
     'SceneOpts.colourBarLabelSide' : 'What side of the colour bar to draw the '
                                      'colour bar labels.',
+    'SceneOpts.colourBarSize'      : 'Size of the major axis of the colour '
+                                     'bar, as a proportion of the available '
+                                     'space.',
     'SceneOpts.performance'        : 'Rendering performance - 1 gives the '
                                      'fastest, but at the cost of lower '
                                      'display quality, and some display '
@@ -410,6 +475,9 @@ properties = TypeDict({
     'to display the scene at the high-DPI resolution. This will have an '
     'effect on performance.',
 
+    'SceneOpts.labelSize'   : 'Scale the label font size.',
+
+
     'OrthoOpts.showXCanvas' : 'Show / hide the X canvas '
                               '(sagittal in MNI space).',
     'OrthoOpts.showYCanvas' : 'Show / hide the Y canvas '
@@ -420,7 +488,6 @@ properties = TypeDict({
     'OrthoOpts.showLabels'  : 'If the currently selected overlay is a NIFTI '
                               'image, show / hide anatomical orientation '
                               'labels.',
-    'OrthoOpts.labelSize'   : 'Scale the label font size.',
     'OrthoOpts.layout'      : 'How to lay out each of the three canvases.',
     'OrthoOpts.zoom'        : 'Zoom level for all three canvases.',
 
@@ -452,8 +519,12 @@ properties = TypeDict({
     'orientation information.',
     'Scene3DOpts.light'      :
     'Enable a simple lighting effect.',
+    'Scene3DOpts.showLight' :
+    'Show the position of the light source.',
     'Scene3DOpts.lightPos' :
     'Position of the light in the display coordinate system.',
+    'Scene3DOpts.lightDistance' :
+    'Distance of the light from the display centre.',
     'Scene3DOpts.occlusion' :
     'When selected, volumes in the scene which are behind another volume will '
     'not be shown. ',
@@ -500,27 +571,34 @@ properties = TypeDict({
     'The axis to loop through. You can choose to run a movie through any '
     'axis of an image (X, Y, Z, or volume/time).',
 
-    'PlotPanel.legend'     : 'Show / hide a legend for series which have '
+    'CanvasPanel.movieSyncRefresh' :
+    'In movie mode, refresh all orthographic canvases in a synchronous '
+    'manner. This is not possible under certain platforms/environments, '
+    'where the canvas updates cannot be synchronised.',
+
+    'PlotCanvas.legend'     : 'Show / hide a legend for series which have '
                              'been added to the plot.',
-    'PlotPanel.xAutoScale' : 'If checked, the plot X axis limits are '
+    'PlotCanvas.xAutoScale' : 'If checked, the plot X axis limits are '
                              'automatically adjusted whenever the plot '
                              'contents change.',
-    'PlotPanel.yAutoScale' : 'If checked, the plot Y axis limits are '
+    'PlotCanvas.yAutoScale' : 'If checked, the plot Y axis limits are '
                              'automatically adjusted whenever the plot '
                              'contents change.',
-    'PlotPanel.xLogScale'  : 'If checked, a log (base 10) scale is used for '
+    'PlotCanvas.xLogScale'  : 'If checked, a log (base 10) scale is used for '
                              'the x axis.',
-    'PlotPanel.yLogScale'  : 'If checked, a log (base 10) scale is used for '
+    'PlotCanvas.yLogScale'  : 'If checked, a log (base 10) scale is used for '
                              'the y axis.',
-    'PlotPanel.ticks'      : 'Show / hide axis ticks and tick labels.',
-    'PlotPanel.grid'       : 'Show hide plot grid.' ,
-    'PlotPanel.gridColour' : 'Set the plot grid colour.' ,
-    'PlotPanel.bgColour'   : 'Set the plot background colour.' ,
-    'PlotPanel.smooth'     : 'Smooth displayed data series (with cubic spline '
+    'PlotCanvas.invertX'    : 'Invert the plot along the X axis.',
+    'PlotCanvas.invertY'    : 'Invert the plot along the Y axis.',
+    'PlotCanvas.ticks'      : 'Show / hide axis ticks and tick labels.',
+    'PlotCanvas.grid'       : 'Show hide plot grid.' ,
+    'PlotCanvas.gridColour' : 'Set the plot grid colour.' ,
+    'PlotCanvas.bgColour'   : 'Set the plot background colour.' ,
+    'PlotCanvas.smooth'     : 'Smooth displayed data series (with cubic spline '
                              'interpolation).',
-    'PlotPanel.xlabel'     : 'Set the x axis label.',
-    'PlotPanel.ylabel'     : 'Set the y axis label.',
-    'PlotPanel.limits'     : 'Manually set the x/y axis limits.',
+    'PlotCanvas.xlabel'     : 'Set the x axis label.',
+    'PlotCanvas.ylabel'     : 'Set the y axis label.',
+    'PlotCanvas.limits'     : 'Manually set the x/y axis limits.',
 
     'TimeSeriesPanel.usePixdim'        : 'If checked, the x axis data is '
                                          'scaled by the time dimension pixdim '
@@ -570,6 +648,37 @@ properties = TypeDict({
     'DataSeries.lineWidth' : 'Line width.',
     'DataSeries.lineStyle' : 'Line style.',
 
+    'ComplexTimeSeries.plotReal' :
+    'Plot the real component of a complex image.',
+    'ComplexTimeSeries.plotImaginary' :
+    'Plot the imaginary component of a complex image.',
+    'ComplexTimeSeries.plotMagnitude' :
+    'Plot the magnitude of a complex image.',
+    'ComplexTimeSeries.plotPhase' :
+    'Plot the phase of a complex image.',
+
+    'ComplexPowerSpectrumSeries.plotReal' :
+    'Plot the real component of the power spectrum of a complex image.',
+    'ComplexPowerSpectrumSeries.plotImaginary' :
+    'Plot the imaginary component of the power spectrum of a complex image.',
+    'ComplexPowerSpectrumSeries.plotMagnitude' :
+    'Plot the magnitude of the power spectrum of a complex image.',
+    'ComplexPowerSpectrumSeries.plotPhase' :
+    'Plot the phase of the power spectrum of a complex image.',
+    'ComplexPowerSpectrumSeries.zeroOrderPhaseCorrection' :
+    'Zero order phase correction',
+    'ComplexPowerSpectrumSeries.firstOrderPhaseCorrection' :
+    'First order phase correction',
+
+    'ComplexHistogramSeries.plotReal' :
+    'Plot the histogram of the real component of a complex image.',
+    'ComplexHistogramSeries.plotImaginary' :
+    'Plot the histogram of the imaginary component of a complex image.',
+    'ComplexHistogramSeries.plotMagnitude' :
+    'Plot the histogram of the magnitude of a complex image.',
+    'ComplexHistogramSeries.plotPhase' :
+    'Plot the histogram of the phase of a complex image.',
+
     'FEATTimeSeries.plotData'         : 'Plot the input data.',
     'FEATTimeSeries.plotFullModelFit' : 'Plot the full model fit.',
     'FEATTimeSeries.plotResiduals'    : 'Plot the residuals of the full '
@@ -604,15 +713,14 @@ properties = TypeDict({
                                         'histogram.',
 
 
-    'PowerSpectrumSeries.varNorm'     : 'If checked, the data is demeaned and '
-                                        'normalised by its standard deviation '
-                                        'before its power spectrum is '
-                                        'calculated via a fourier transform.',
+    'PowerSpectrumSeries.varNorm' :
+    'If checked, the fourier-transformed data is normalised to the range '
+    '[-1, 1]. Complex valued data are normalised with respect to the '
+    'absolute value. ',
 
     # Profiles
-
-    'OrthoPanel.profile'                      : 'Switch between view mode '
-                                                'and edit mode',
+    'OrthoPanel.profile' :
+    'Switch between view mode and edit mode',
 
     'OrthoEditProfile.selectionCursorColour'  :
     'Colour to use for the selection cursor.',
@@ -700,11 +808,10 @@ properties = TypeDict({
 
 actions = TypeDict({
     'CanvasPanel.screenshot'        : 'Take a screenshot of the current scene',
-    'CanvasPanel.toggleDisplayPanel' : 'Show more overlay display settings',
-    'CanvasPanel.toggleCanvasSettingsPanel' : 'Show more view '
-                                              'control settings',
-    'CanvasPanel.toggleOverlayInfo' : 'Show/hide the overlay '
-                                      'information panel.',
+    'CanvasPanel.OverlayDisplayPanel' : 'Show more overlay display settings',
+    'CanvasPanel.CanvasSettingsPanel' : 'Show more view control settings',
+    'CanvasPanel.OverlayInfoPanel'    : 'Show/hide the overlay '
+                                        'information panel.',
 
     'OrthoPanel.toggleEditPanel' : 'Show/hide the edit settings panel',
 
@@ -716,23 +823,22 @@ actions = TypeDict({
     'PlotPanel.removeDataSeries' : 'Remove the most recently '
                                    'added data series.',
 
-    'TimeSeriesPanel.toggleTimeSeriesControl' : 'Show/hide the time '
+    'TimeSeriesPanel.TimeSeriesControlPanel'  : 'Show/hide the time '
                                                 'series control panel.',
-    'TimeSeriesPanel.togglePlotList'          : 'Show/hide the time '
+    'TimeSeriesPanel.PlotListPanel'           : 'Show/hide the time '
                                                 'series list panel.',
-    'HistogramPanel.toggleHistogramControl'   : 'Show/hide the histogram '
+    'HistogramPanel.HistogramControlPanel'    : 'Show/hide the histogram '
                                                 'control panel.',
-    'HistogramPanel.togglePlotList'           : 'Show/hide the histogram '
+    'HistogramPanel.PlotListPanel'            : 'Show/hide the histogram '
                                                 'list panel.',
 
-    'PowerSpectrumPanel.togglePowerSpectrumControl' : 'Show/hide the power '
+    'PowerSpectrumPanel.PowerSpectrumControlPanel'  : 'Show/hide the power '
                                                       'spectrum control '
                                                       'panel.',
-    'PowerSpectrumPanel.togglePlotList'             : 'Show/hide the power '
+    'PowerSpectrumPanel.PlotListPanel'              : 'Show/hide the power '
                                                       'spectrum list '
                                                       'panel.',
 
-
     'OrthoViewProfile.resetDisplay' : 'Reset the display on all canvases.',
     'OrthoViewProfile.centreCursor' : 'Reset location to centre of scene',
 
@@ -759,14 +865,19 @@ actions = TypeDict({
     'Set the value at all selected voxels in the currently selected '
     'image to zero.',
 
-    'OrthoEditProfile.copySelection' :
-    'Copy the values of all selected voxels in the currently selected image '
-    'and store them in an internal clipboard. The voxel values can then be '
-    'pasted into another image (which has the same dimensions/resolution as '
-    'the source image).',
+    'OrthoEditProfile.copyPasteData' :
+    'Copy/paste data between images. Select some voxels in one image, and '
+    'click this button to copy the voxel values to a clipboard. Then select '
+    'another image (which has the same dimensions/resolution as the first '
+    'image), and click this button again to paste the values. Shift+click the '
+    'button to clear the clipboard.',
 
-    'OrthoEditProfile.pasteSelection' :
-    'Paste the contents of the clipboard into the currently selected image.',
+    'OrthoEditProfile.copyPasteSelection' :
+    'Copy/paste 2D selections between slices. Draw a selection on one slice, '
+    'and push this button to copy the selection from that slice. Then move .'
+    'the cursor to a different slice, and push this button again to paste the '
+    'selection into the new slice. Shift+click the button to clear the '
+    'clipboard.',
 
     'Scene3DViewProfile.resetDisplay' :
     'Reset the zoom, pan, and rotation',
@@ -776,16 +887,45 @@ actions = TypeDict({
     'ListItemWidget.group' : 'Link some properties of this overlay '
                              'with other linked overlays (e.g. '
                              'volume)',
+
+    'SampleLinePanel.screenshot' : 'Save the plot to a file',
+    'SampleLinePanel.addDataSeries'    :
+    'Add (hold) the most recently drawn data series.',
+    'SampleLinePanel.removeDataSeries' :
+    'Remove the most recently added data series.',
+
+    'AnnotationPanel.loadAnnotations' :
+    'Load annotations from a file',
+    'AnnotationPanel.saveAnnotations' :
+    'Save the currently displayed annotations to a file',
 })
 
 
 misc = TypeDict({
     'PlotControlPanel.labels' : 'X/Y axis labels.',
+    'PlotControlPanel.logscale' :
+    'If checked, a log (base 10) scale is used for the X/Y axis.',
+    'PlotControlPanel.autoscale' :
+    'If checked, the plot X/Y axis limits are automatically adjusted whenever '
+    'the plot contents change.',
+    'PlotControlPanel.invert' :
+    'If checked, the plot is inverted along the X/Y axis.',
+    'PlotControlPanel.scale' :
+    'A constant scaling factor to apply to the data.',
+    'PlotControlPanel.offset' :
+    'A constant offset to apply to the data.',
+
     'PlotControlPanel.xlim'   : 'X axis data limits.',
     'PlotControlPanel.ylim'   : 'Y axis data limits.',
 
+    'ResampleDialog.reference' :
+    'Resample the image to the same dimensions as this reference.',
     'ResampleDialog.interpolation' :
     'The interpolation approach to use when resampling.',
+    'ResampleDialog.origin' :
+    'The origin common to the original space and the resampled space - .'
+    'either the centre of the corner voxel, or the corner of the corner '
+    'voxel.',
     'ResampleDialog.dtype' :
     'The data type of the resampled image. If you are resampling and '
     'interpolating an image with an integer data type, you may need to select '
@@ -797,4 +937,8 @@ misc = TypeDict({
     'voxels. This setting has no effect when using nearest neighbour '
     'interpolation, and is only applied along axes which are being '
     'down-sampled.',
+    'ResampleDialog.allVolumes' :
+    'For images with more than three dimensions, this checkbox controls '
+    'whether all volumes are resampled, or just the currently selected '
+    'volume.',
 })
